#[repr(transparent)]pub struct GpioCtrl(pub u32);Expand description
GPIO control including function select and overrides.
Tuple Fields
0: u32Implementations
Sourceimpl GpioCtrl
impl GpioCtrl
Sourcepub const fn funcsel(&self) -> u8
pub const fn funcsel(&self) -> u8
0-31 -> selects pin function according to the gpio table 31 == NULL
Sourcepub const fn set_funcsel(&mut self, val: u8)
pub const fn set_funcsel(&mut self, val: u8)
0-31 -> selects pin function according to the gpio table 31 == NULL
pub const fn outover(&self) -> Outover
pub const fn set_outover(&mut self, val: Outover)
pub const fn oeover(&self) -> Oeover
pub const fn set_oeover(&mut self, val: Oeover)
pub const fn inover(&self) -> Inover
pub const fn set_inover(&mut self, val: Inover)
pub const fn irqover(&self) -> Irqover
pub const fn set_irqover(&mut self, val: Irqover)